Continuous joint, constraining two objects to rotate around a given axis, without limits.
This can be seen as a revolute joint without limits. On top of that, the parametrization of the configuration is different: instead of using an angle $\theta \in [-\pi, \pi]$, continuous joints use unit circle parametrization $(\cos(\theta), \sin(\theta))$.
Structs
- Joint
Data Continuous - Data structure containing the mutable properties of a continuous joint.
- Joint
Model Continuous - Model of a continuous joint.