pub struct JointDataContinuous {
pub joint_q: Configuration,
pub joint_v: Configuration,
pub placement: SE3,
pub joint_velocity: SpatialMotion,
}Expand description
Data structure containing the mutable properties of a continuous joint.
Fields
joint_q: ConfigurationThe joint configuration vector (cosine and sine of the angle).
joint_v: ConfigurationThe joint velocity vector (angular velocity).
placement: SE3The placement of the joint in the local frame.
joint_velocity: SpatialMotionThe joint velocity as a spatial motion.
Implementations
Sourceimpl JointDataContinuous
impl JointDataContinuous
Sourcepub fn new(_joint_model: &JointModelContinuous) -> Self
pub fn new(_joint_model: &JointModelContinuous) -> Self