JointModelContinuous

Struct JointModelContinuous 

pub struct JointModelContinuous {
    pub axis: SpatialMotion,
    pub limits: JointLimits,
    pub bias: SpatialMotion,
}
Model of a continuous joint.

This joint constraints two objects to rotate around a given axis, without limits.

Fields

axis: SpatialMotion

The axis of rotation expressed in the local frame of the joint.

limits: JointLimits

The joint limits.

bias: SpatialMotion

The (null) bias of the joint.

Implementations

Source

impl JointModelContinuous

pub fn new(axis: Vector3D) -> Self

Creates a new JointModelContinuous with the given axis of rotation and unbounded limits.

The axis of rotation should be normalized and expressed in the local frame of the joint.

Arguments
  • axis - The normalized axis of rotation expressed in the local frame of the joint.
Returns

A new JointModelContinuous object.

pub fn new_rux() -> Self

Creates a new continuous joint model with x as axis of rotation.

Returns

A new JointModelContinuous object.

pub fn new_ruy() -> Self

Creates a new continuous joint model with y as axis of rotation.

Returns

A new JointModelContinuous object.

pub fn new_ruz() -> Self

Creates a new continuous joint model with z as axis of rotation.

Returns

A new JointModelContinuous object.