pub struct JointDataFixed {
pub joint_q: Configuration,
pub joint_v: Configuration,
pub placement: SE3,
pub joint_velocity: SpatialMotion,
}Expand description
Data structure containing the mutable properties of a fixed joint.
Fields
joint_q: ConfigurationThe joint configuration vector (always empty).
joint_v: ConfigurationThe joint velocity vector (always empty).
placement: SE3The placement of the joint in the local frame.
joint_velocity: SpatialMotionThe joint velocity as a spatial motion.
Implementations
Sourceimpl JointDataFixed
impl JointDataFixed
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new JointDataFixed from given joint model.
Arguments
joint_model- The fixed joint model.
Returns
A new JointDataFixed object.