JointDataWrapper

Struct JointDataWrapper 

pub struct JointDataWrapper { /* private fields */ }
Wrapper struct for different joint data implementations.

This struct provides a unified interface to interact with different joint types through the JointData trait. It serves as the main entry point for users of the library to work with joints data.

Implementations

Source

impl JointDataWrapper

pub fn continuous(joint_data: JointDataContinuous) -> Self

Creates a new JointDataWrapper from a JointDataContinuous.

pub fn prismatic(joint_data: JointDataPrismatic) -> Self

Creates a new JointDataWrapper from a JointDataPrismatic.

pub fn revolute(joint_data: JointDataRevolute) -> Self

Creates a new JointDataWrapper from a JointDataRevolute.

pub fn fixed(joint_data: JointDataFixed) -> Self

Creates a new JointDataWrapper from a JointDataFixed.