JointData

Trait JointData 

pub trait JointData {
    // Required methods
    fn get_joint_q(&self) -> &Configuration;
    fn get_joint_v(&self) -> &Configuration;
    fn get_joint_placement(&self) -> SE3;
    fn update(
        &mut self,
        joint_model: &JointWrapper,
        joint_q: &Configuration,
        joint_v: Option<&Configuration>,
    );
    fn get_joint_velocity(&self) -> &SpatialMotion;
}
Trait for joint data, providing methods to access and update joint properties.

Required Methods

fn get_joint_q(&self) -> &Configuration

Returns the joint configuration vector.

fn get_joint_v(&self) -> &Configuration

Returns the joint velocity vector.

fn get_joint_placement(&self) -> SE3

Returns the placement of the joint in the world frame.

fn update( &mut self, joint_model: &JointWrapper, joint_q: &Configuration, joint_v: Option<&Configuration>, )

Updates the joint data with the current position and velocity configurations.

fn get_joint_velocity(&self) -> &SpatialMotion

Returns the joint velocity as a spatial motion.

Implementors