pub struct JointModelPrismatic {
pub axis: SpatialMotion,
pub limits: JointLimits,
pub bias: SpatialMotion,
}Expand description
Model of a prismatic joint.
This joint constraints two objects to translate along a given axis.
Fields
axis: SpatialMotionThe axis of translation expressed in the local frame of the joint.
limits: JointLimitsThe joint limits.
bias: SpatialMotionThe (null) bias of the joint.
Implementations
Sourceimpl JointModelPrismatic
impl JointModelPrismatic
Sourcepub fn new(axis: Vector3D) -> Self
pub fn new(axis: Vector3D) -> Self
Creates a new JointModelPrismatic with the given axis of translation and unbounded limits.
The axis of translation should be normalized and expressed in the local frame of the joint.
Arguments
axis- The normalized axis of translation expressed in the local frame of the joint.
Returns
A new JointModelPrismatic object.
Sourcepub fn new_px() -> Self
pub fn new_px() -> Self
Creates a new prismatic joint model with x as axis of translation.
Returns
A new JointModelPrismatic object.