pub struct JointDataRevolute {
pub joint_q: Configuration,
pub joint_v: Configuration,
pub placement: SE3,
pub joint_velocity: SpatialMotion,
}Expand description
Data structure containing the mutable properties of a revolute joint.
Fields
joint_q: ConfigurationThe joint configuration vector (angle of rotation).
joint_v: ConfigurationThe joint velocity vector (angle velocity).
placement: SE3The placement of the joint in the local frame.
joint_velocity: SpatialMotionThe joint velocity as a spatial motion.
Implementations
Sourceimpl JointDataRevolute
impl JointDataRevolute
Sourcepub fn new(_joint_model: &JointModelRevolute) -> Self
pub fn new(_joint_model: &JointModelRevolute) -> Self