pub struct JointModelRevolute {
pub axis: SpatialMotion,
pub limits: JointLimits,
pub bias: SpatialMotion,
}Expand description
Model of a revolute joint.
This joint constraints two objects to rotate around a given axis.
Fields
axis: SpatialMotionThe axis of rotation expressed in the local frame of the joint.
limits: JointLimitsThe joint limits.
bias: SpatialMotionThe (null) bias of the joint.
Implementations
Sourceimpl JointModelRevolute
impl JointModelRevolute
Sourcepub fn new(axis: Vector3D) -> Self
pub fn new(axis: Vector3D) -> Self
Creates a new JointModelRevolute with the given axis of rotation and unbounded limits.
The axis of rotation should be normalized and expressed in the local frame of the joint.
Arguments
axis- The normalized axis of rotation expressed in the local frame of the joint.
Returns
A new JointModelRevolute object.
Sourcepub fn new_rx() -> Self
pub fn new_rx() -> Self
Creates a new revolute joint model with x as axis of rotation.
Returns
A new JointModelRevolute object.