pub struct JointModelContinuous {
pub axis: Vector3D,
pub limits: JointLimits,
}Expand description
Model of a continuous joint.
This joint constraints two objects to rotate around a given axis, without limits.
Fields
axis: Vector3DThe axis of rotation expressed in the local frame of the joint.
limits: JointLimitsThe joint limits.
Implementations
Sourceimpl JointModelContinuous
impl JointModelContinuous
Sourcepub fn new_rux() -> Self
pub fn new_rux() -> Self
Creates a new continuous joint model with x as axis of rotation.
Returns
A new JointModelContinuous object.