pub struct JointWrapper { /* private fields */ }Expand description
Wrapper struct for different joint model implementations.
This struct provides a unified interface to interact with different joint types
through the JointModel trait. It serves as the main entry point for users of
the library to work with joints.
Implementations
Sourceimpl JointWrapper
impl JointWrapper
Sourcepub fn continuous(joint: JointModelContinuous) -> Self
pub fn continuous(joint: JointModelContinuous) -> Self
Creates a new JointWrapper from a JointModelContinuous.
Sourcepub fn prismatic(joint: JointModelPrismatic) -> Self
pub fn prismatic(joint: JointModelPrismatic) -> Self
Creates a new JointWrapper from a JointModelPrismatic.
Sourcepub fn revolute(joint: JointModelRevolute) -> Self
pub fn revolute(joint: JointModelRevolute) -> Self
Creates a new JointWrapper from a JointModelRevolute.
Sourcepub fn fixed(joint: JointModelFixed) -> Self
pub fn fixed(joint: JointModelFixed) -> Self
Creates a new JointWrapper from a JointModelFixed.